#
# spec file for package libsigsegv
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define somajor	2
%define lname	  libsigsegv%{somajor}
Name:           libsigsegv
Version:        2.14
Release:        2.10
Summary:        Library for Handling Page Faults in User Mode
License:        GPL-2.0-or-later
Group:          System/Libraries
URL:            https://www.gnu.org/software/libsigsegv/
Source0:        https://ftp.gnu.org/pub/gnu/libsigsegv/libsigsegv-%{version}.tar.gz
Source1:        https://ftp.gnu.org/pub/gnu/libsigsegv/libsigsegv-%{version}.tar.gz.sig
Source2:        http://savannah.gnu.org/people/viewgpg.php?user_id=1871#/%{name}.keyring
Patch0:         libsigsegv-2.12-lto.dif
BuildRequires:  pkgconfig

%define add_optflags(a:f:t:p:w:W:d:g:O:A:C:D:E:H:i:M:n:P:U:u:l:s:X:B:I:L:b:V:m:x:c:S:E:o:v:) \
%global optflags %{optflags} %{**}

%description
This is a library for handling page faults in user mode. A page fault occurs
when a program tries to access to a region of memory that is currently not
available.

%package -n %{lname}
Summary:        Library for Handling Page Faults in User Mode
Group:          System/Libraries

%description -n %{lname}
This is a library for handling page faults in user mode. A page fault occurs
when a program tries to access to a region of memory that is currently not
available.

%package devel
Summary:        Library for Handling Page Faults in User Mode
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}-%{release}

%description devel
This is a library for handling page faults in user mode. A page fault occurs
when a program tries to access to a region of memory that is currently not
available.

%package doc
Summary:        Library for Handling Page Faults in User Mode
Group:          Documentation/Other

%description doc
This is a library for handling page faults in user mode. A page fault occurs
when a program tries to access to a region of memory that is currently not
available.

%prep
%setup -q
%patch0 -b .p0

%build
%add_optflags -g3 -D_DEFAULT_SOURCE -D_XOPEN_SOURCE
%if 0%(case "%optflags" in (*-flto*) echo 1;; esac)
%add_optflags -ffat-lto-objects
%endif
%configure \
	--with-gnu-ld   \
	--enable-shared \
	--enable-static
sed -ri 's@^((old_striplib|striplib)=)".*"@\1""@' libtool
sed -ri 's@^(hardcode_libdir_flag_spec=)".*"@\1""@' libtool
mkdir bin/
ln -sf /bin/true bin/strip
PATH=${PWD}/bin:$PATH; export PATH
make %{?_smp_mflags}

%install
%make_install
rm "%{buildroot}%{_libdir}/libsigsegv.la"

%check
%if 0%{?qemu_user_space_build}
# qemu does not support stack overflows well
export XFAIL_TESTS="test-catch-stackoverflow1 test-catch-stackoverflow2"
%endif
make %{?_smp_mflags} check

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files doc
%if %{defined license}
%license COPYING
%doc AUTHORS ChangeLog* NEWS PORTING README
%else
%doc AUTHORS COPYING ChangeLog* NEWS PORTING README
%endif

%files -n %{lname}
%{_libdir}/libsigsegv.so.%{somajor}*

%files devel
%{_includedir}/sigsegv.h
%{_libdir}/libsigsegv.so
%{_libdir}/libsigsegv.a

%changelog
* Mon Jan 10 2022 Andreas Schwab <schwab@suse.de>
- test-catch-stackoverflow1 and test-catch-stackoverflow2 are expected to
  fail under qemu
* Fri Jan  7 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.14:
  * Improved support for Linux/LoongArch64
* Tue Jan 19 2021 Dirk Müller <dmueller@suse.com>
- update to 2.13:
  * Added support for macOS/arm64.
  * Added support for Solaris OpenIndiana.
  * Added support for catching stack overflow on Solaris 11/SPARC.
  * Added support for catching stack overflow on 64-bit Haiku.
  * Provide a correct value for SIGSTKSZ on 64-bit Solaris/x86. The one defined
    by this system is too small.
  * Improved support for Linux/RISC-V, Linux/nds32.
  * Improved support for Android.
  * Improved support for FreeBSD/x86, FreeBSD/x86_64, FreeBSD/arm, FreeBSD/arm64.
  * Improved support for 64-bit ABI on Solaris/x86_64.
* Fri Apr 26 2019 Dr. Werner Fink <werner@suse.de>
- Allow LTO but only FAT LTO OBJECTS (boo#1133245)
* Thu Apr 25 2019 Dr. Werner Fink <werner@suse.de>
- Add patch libsigsegv-2.12-lto.dif
  * Avoid redefinition of structures of <bits/sigcontext.h> by
    <asm/sigcontext.h>
  * Avoid moved logic in resulting assembler code for LTO objects
    in signal handler for segmentation faults
* Thu Apr 25 2019 Dr. Werner Fink <werner@suse.de>
- Avoid none debugging libsigsegv, that is add -fno-lto (boo#1133245)
- Use %%license if known
* Wed Apr 24 2019 Martin Liška <mliska@suse.cz>
- Disable LTO (boo#1133245).
* Thu Feb  1 2018 astieger@suse.com
- update to 2.12:
  * updates for platform other than GNU/Linux
  * Reliability improvements
* Mon May 22 2017 mpluskal@suse.com
- Add gpg signature
- Small spec file cleanup with spec-cleaner
- Trim dependencies
* Wed Feb 22 2017 werner@suse.de
- Update to version 2.11
  * Added support for catching stack overflow on Linux/SPARC.
  * Provide a correct value for SIGSTKSZ on 64-bit AIX and on HP-UX. The one
    defined by these systems is too small.
  * Updated build infrastructure.
  * Compilation now requires the <stdint.h> include file. Platforms which
  don't have this include file (such as IRIX) are no longer supported.
  * NOTE: Support for Cygwin and native Windows is currently not up-to-date.
- Update URL that is use https://www.gnu.org/software/libsigsegv/
* Wed Jul  3 2013 schwab@suse.de
- fix-build-in-qemu.patch: Remove, set XFAIL_TESTS instead
- Reenable testsuite on armv7
* Wed May  8 2013 werner@suse.de
- Update to version 2.10
- Adopt patch fix-build-in-qemu.patch
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Fri Dec  3 2010 pascal.bleser@opensuse.org
- initial package (2.9)
